pub struct CompactHeaderData {
pub daa_score: u64,
pub timestamp: u64,
pub bits: u32,
pub blue_score: u64,
}Fields
daa_score: u64timestamp: u64bits: u32blue_score: u64Trait Implementations
Sourceimpl Clone for CompactHeaderData
impl Clone for CompactHeaderData
Sourcefn clone(&self) -> CompactHeaderData
fn clone(&self) -> CompactHeaderData
Returns a duplicate of the value. Read more
1.0.0fn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for CompactHeaderData
impl<'de> Deserialize<'de> for CompactHeaderData
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<&Header> for CompactHeaderData
impl From<&Header> for CompactHeaderData
Sourceimpl MemSizeEstimator for CompactHeaderData
impl MemSizeEstimator for CompactHeaderData
Sourcefn estimate_size(&self, mem_mode: MemMode) -> usize
fn estimate_size(&self, mem_mode: MemMode) -> usize
Estimates the size of this object depending on the passed mem mode
Sourcefn estimate_mem_bytes(&self) -> usize
fn estimate_mem_bytes(&self) -> usize
Estimates the (deep) size of this object in bytes (including heap owned inner data)
Sourcefn estimate_mem_units(&self) -> usize
fn estimate_mem_units(&self) -> usize
Estimates the number of units this object holds in memory where the unit byte size is usually
a constant known to the caller as well (and hence we avoid computing it over and over)
Sourceimpl Serialize for CompactHeaderData
impl Serialize for CompactHeaderData
impl Copy for CompactHeaderData