pub struct HeaderWithBlockLevel {
pub header: Arc<Header>,
pub block_level: BlockLevel,
}Fields
header: Arc<Header>block_level: BlockLevelTrait Implementations
Sourceimpl Clone for HeaderWithBlockLevel
impl Clone for HeaderWithBlockLevel
Sourcefn clone(&self) -> HeaderWithBlockLevel
fn clone(&self) -> HeaderWithBlockLevel
Returns a duplicate of the value. Read more
1.0.0fn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for HeaderWithBlockLevel
impl<'de> Deserialize<'de> for HeaderWithBlockLevel
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl MemSizeEstimator for HeaderWithBlockLevel
impl MemSizeEstimator for HeaderWithBlockLevel
Sourcefn estimate_mem_bytes(&self) -> usize
fn estimate_mem_bytes(&self) -> usize
Estimates the (deep) size of this object in bytes (including heap owned inner data)
Sourcefn estimate_size(&self, mem_mode: MemMode) -> usize
fn estimate_size(&self, mem_mode: MemMode) -> usize
Estimates the size of this object depending on the passed mem mode
Sourcefn estimate_mem_units(&self) -> usize
fn estimate_mem_units(&self) -> usize
Estimates the number of units this object holds in memory where the unit byte size is usually
a constant known to the caller as well (and hence we avoid computing it over and over)