SyncManager

Struct SyncManager 

pub struct SyncManager<S: RelationsStoreReader, T: ReachabilityStoreReader, U: GhostdagStoreReader, V: SelectedChainStoreReader, W: HeadersSelectedTipStoreReader, X: PruningStoreReader, Y: StatusesStoreReader> { /* private fields */ }

Implementations

Source

impl<S: RelationsStoreReader, T: ReachabilityStoreReader, U: GhostdagStoreReader, V: SelectedChainStoreReader, W: HeadersSelectedTipStoreReader, X: PruningStoreReader, Y: StatusesStoreReader> SyncManager<S, T, U, V, W, X, Y>

pub fn new( mergeset_size_limit: usize, reachability_service: MTReachabilityService<T>, traversal_manager: DagTraversalManager<U, T, S>, ghostdag_store: Arc<U>, selected_chain_store: Arc<RwLock<V>>, header_selected_tip_store: Arc<RwLock<W>>, pruning_point_store: Arc<RwLock<X>>, statuses_store: Arc<RwLock<Y>>, ) -> Self

pub fn antipast_hashes_between( &self, low: Hash, high: Hash, max_blocks: Option<usize>, ) -> (Vec<Hash>, Hash)

Returns the hashes of the blocks between low’s antipast and high’s antipast, or up to max_blocks, if provided. The result excludes low and includes high. If low == high, returns nothing. If max_blocks is some then it MUST be >= MergeSetSizeLimit because it returns blocks with MergeSet granularity, so if MergeSet > max_blocks, the function will return nothing which is undesired behavior.

pub fn find_highest_common_chain_block(&self, low: Hash, high: Hash) -> Hash

pub fn create_virtual_selected_chain_block_locator( &self, low: Option<Hash>, high: Option<Hash>, ) -> SyncManagerResult<Vec<Hash>>

Returns a logarithmic amount of blocks sampled from the virtual selected chain between low and high. Expects both blocks to be on the virtual selected chain, otherwise an error is returned

pub fn get_missing_block_body_hashes( &self, high: Hash, ) -> SyncManagerResult<Vec<Hash>>

pub fn create_block_locator_from_pruning_point( &self, high: Hash, low: Hash, limit: Option<usize>, ) -> SyncManagerResult<Vec<Hash>>